from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.DistributedTransactionCoordinator
import win32more.Windows.Win32.System.IO
import win32more.Windows.Win32.System.MessageQueuing
import win32more.Windows.Win32.System.Variant
PRLT: UInt32 = 0
PRLE: UInt32 = 1
PRGT: UInt32 = 2
PRGE: UInt32 = 3
PREQ: UInt32 = 4
PRNE: UInt32 = 5
QUERY_SORTASCEND: UInt32 = 0
QUERY_SORTDESCEND: UInt32 = 1
MQ_MOVE_ACCESS: UInt32 = 4
MQ_ACTION_RECEIVE: UInt32 = 0
MQ_ACTION_PEEK_CURRENT: UInt32 = 2147483648
MQ_ACTION_PEEK_NEXT: UInt32 = 2147483649
MQ_LOOKUP_PEEK_CURRENT: UInt32 = 1073741840
MQ_LOOKUP_PEEK_NEXT: UInt32 = 1073741841
MQ_LOOKUP_PEEK_PREV: UInt32 = 1073741842
MQ_LOOKUP_PEEK_FIRST: UInt32 = 1073741844
MQ_LOOKUP_PEEK_LAST: UInt32 = 1073741848
MQ_LOOKUP_RECEIVE_CURRENT: UInt32 = 1073741856
MQ_LOOKUP_RECEIVE_NEXT: UInt32 = 1073741857
MQ_LOOKUP_RECEIVE_PREV: UInt32 = 1073741858
MQ_LOOKUP_RECEIVE_FIRST: UInt32 = 1073741860
MQ_LOOKUP_RECEIVE_LAST: UInt32 = 1073741864
MQ_LOOKUP_RECEIVE_ALLOW_PEEK: UInt32 = 1073742112
PROPID_M_BASE: UInt32 = 0
PROPID_M_CLASS: UInt32 = 1
PROPID_M_MSGID: UInt32 = 2
PROPID_M_CORRELATIONID: UInt32 = 3
PROPID_M_PRIORITY: UInt32 = 4
PROPID_M_DELIVERY: UInt32 = 5
PROPID_M_ACKNOWLEDGE: UInt32 = 6
PROPID_M_JOURNAL: UInt32 = 7
PROPID_M_APPSPECIFIC: UInt32 = 8
PROPID_M_BODY: UInt32 = 9
PROPID_M_BODY_SIZE: UInt32 = 10
PROPID_M_LABEL: UInt32 = 11
PROPID_M_LABEL_LEN: UInt32 = 12
PROPID_M_TIME_TO_REACH_QUEUE: UInt32 = 13
PROPID_M_TIME_TO_BE_RECEIVED: UInt32 = 14
PROPID_M_RESP_QUEUE: UInt32 = 15
PROPID_M_RESP_QUEUE_LEN: UInt32 = 16
PROPID_M_ADMIN_QUEUE: UInt32 = 17
PROPID_M_ADMIN_QUEUE_LEN: UInt32 = 18
PROPID_M_VERSION: UInt32 = 19
PROPID_M_SENDERID: UInt32 = 20
PROPID_M_SENDERID_LEN: UInt32 = 21
PROPID_M_SENDERID_TYPE: UInt32 = 22
PROPID_M_PRIV_LEVEL: UInt32 = 23
PROPID_M_AUTH_LEVEL: UInt32 = 24
PROPID_M_AUTHENTICATED: UInt32 = 25
PROPID_M_HASH_ALG: UInt32 = 26
PROPID_M_ENCRYPTION_ALG: UInt32 = 27
PROPID_M_SENDER_CERT: UInt32 = 28
PROPID_M_SENDER_CERT_LEN: UInt32 = 29
PROPID_M_SRC_MACHINE_ID: UInt32 = 30
PROPID_M_SENTTIME: UInt32 = 31
PROPID_M_ARRIVEDTIME: UInt32 = 32
PROPID_M_DEST_QUEUE: UInt32 = 33
PROPID_M_DEST_QUEUE_LEN: UInt32 = 34
PROPID_M_EXTENSION: UInt32 = 35
PROPID_M_EXTENSION_LEN: UInt32 = 36
PROPID_M_SECURITY_CONTEXT: UInt32 = 37
PROPID_M_CONNECTOR_TYPE: UInt32 = 38
PROPID_M_XACT_STATUS_QUEUE: UInt32 = 39
PROPID_M_XACT_STATUS_QUEUE_LEN: UInt32 = 40
PROPID_M_TRACE: UInt32 = 41
PROPID_M_BODY_TYPE: UInt32 = 42
PROPID_M_DEST_SYMM_KEY: UInt32 = 43
PROPID_M_DEST_SYMM_KEY_LEN: UInt32 = 44
PROPID_M_SIGNATURE: UInt32 = 45
PROPID_M_SIGNATURE_LEN: UInt32 = 46
PROPID_M_PROV_TYPE: UInt32 = 47
PROPID_M_PROV_NAME: UInt32 = 48
PROPID_M_PROV_NAME_LEN: UInt32 = 49
PROPID_M_FIRST_IN_XACT: UInt32 = 50
PROPID_M_LAST_IN_XACT: UInt32 = 51
PROPID_M_XACTID: UInt32 = 52
PROPID_M_AUTHENTICATED_EX: UInt32 = 53
PROPID_M_RESP_FORMAT_NAME: UInt32 = 54
PROPID_M_RESP_FORMAT_NAME_LEN: UInt32 = 55
PROPID_M_DEST_FORMAT_NAME: UInt32 = 58
PROPID_M_DEST_FORMAT_NAME_LEN: UInt32 = 59
PROPID_M_LOOKUPID: UInt32 = 60
PROPID_M_SOAP_ENVELOPE: UInt32 = 61
PROPID_M_SOAP_ENVELOPE_LEN: UInt32 = 62
PROPID_M_COMPOUND_MESSAGE: UInt32 = 63
PROPID_M_COMPOUND_MESSAGE_SIZE: UInt32 = 64
PROPID_M_SOAP_HEADER: UInt32 = 65
PROPID_M_SOAP_BODY: UInt32 = 66
PROPID_M_DEADLETTER_QUEUE: UInt32 = 67
PROPID_M_DEADLETTER_QUEUE_LEN: UInt32 = 68
PROPID_M_ABORT_COUNT: UInt32 = 69
PROPID_M_MOVE_COUNT: UInt32 = 70
PROPID_M_LAST_MOVE_TIME: UInt32 = 75
PROPID_M_MSGID_SIZE: UInt32 = 20
PROPID_M_CORRELATIONID_SIZE: UInt32 = 20
PROPID_M_XACTID_SIZE: UInt32 = 20
MQMSG_PRIV_LEVEL_BODY_AES: UInt32 = 5
MQMSG_AUTHENTICATED_QM_MESSAGE: UInt32 = 11
MQMSG_NOT_FIRST_IN_XACT: UInt32 = 0
MQMSG_FIRST_IN_XACT: UInt32 = 1
MQMSG_NOT_LAST_IN_XACT: UInt32 = 0
MQMSG_LAST_IN_XACT: UInt32 = 1
PROPID_Q_BASE: UInt32 = 100
PROPID_Q_INSTANCE: UInt32 = 101
PROPID_Q_TYPE: UInt32 = 102
PROPID_Q_PATHNAME: UInt32 = 103
PROPID_Q_JOURNAL: UInt32 = 104
PROPID_Q_QUOTA: UInt32 = 105
PROPID_Q_BASEPRIORITY: UInt32 = 106
PROPID_Q_JOURNAL_QUOTA: UInt32 = 107
PROPID_Q_LABEL: UInt32 = 108
PROPID_Q_CREATE_TIME: UInt32 = 109
PROPID_Q_MODIFY_TIME: UInt32 = 110
PROPID_Q_AUTHENTICATE: UInt32 = 111
PROPID_Q_PRIV_LEVEL: UInt32 = 112
PROPID_Q_TRANSACTION: UInt32 = 113
PROPID_Q_PATHNAME_DNS: UInt32 = 124
PROPID_Q_MULTICAST_ADDRESS: UInt32 = 125
PROPID_Q_ADS_PATH: UInt32 = 126
MQ_QTYPE_REPORT: Guid = Guid('{55ee8f32-cce9-11cf-b108-0020afd61ce9}')
MQ_QTYPE_TEST: Guid = Guid('{55ee8f33-cce9-11cf-b108-0020afd61ce9}')
PROPID_QM_BASE: UInt32 = 200
PROPID_QM_SITE_ID: UInt32 = 201
PROPID_QM_MACHINE_ID: UInt32 = 202
PROPID_QM_PATHNAME: UInt32 = 203
PROPID_QM_CONNECTION: UInt32 = 204
PROPID_QM_ENCRYPTION_PK: UInt32 = 205
PROPID_QM_ENCRYPTION_PK_BASE: UInt32 = 231
PROPID_QM_ENCRYPTION_PK_ENHANCED: UInt32 = 232
PROPID_QM_PATHNAME_DNS: UInt32 = 233
PROPID_QM_ENCRYPTION_PK_AES: UInt32 = 244
PROPID_PC_BASE: UInt32 = 5800
PROPID_PC_VERSION: UInt32 = 5801
PROPID_PC_DS_ENABLED: UInt32 = 5802
PROPID_MGMT_MSMQ_BASE: UInt32 = 0
PROPID_MGMT_MSMQ_ACTIVEQUEUES: UInt32 = 1
PROPID_MGMT_MSMQ_PRIVATEQ: UInt32 = 2
PROPID_MGMT_MSMQ_DSSERVER: UInt32 = 3
PROPID_MGMT_MSMQ_CONNECTED: UInt32 = 4
PROPID_MGMT_MSMQ_TYPE: UInt32 = 5
PROPID_MGMT_MSMQ_BYTES_IN_ALL_QUEUES: UInt32 = 6
MSMQ_CONNECTED: String = 'CONNECTED'
MSMQ_DISCONNECTED: String = 'DISCONNECTED'
PROPID_MGMT_QUEUE_BASE: UInt32 = 0
PROPID_MGMT_QUEUE_PATHNAME: UInt32 = 1
PROPID_MGMT_QUEUE_FORMATNAME: UInt32 = 2
PROPID_MGMT_QUEUE_TYPE: UInt32 = 3
PROPID_MGMT_QUEUE_LOCATION: UInt32 = 4
PROPID_MGMT_QUEUE_XACT: UInt32 = 5
PROPID_MGMT_QUEUE_FOREIGN: UInt32 = 6
PROPID_MGMT_QUEUE_MESSAGE_COUNT: UInt32 = 7
PROPID_MGMT_QUEUE_BYTES_IN_QUEUE: UInt32 = 8
PROPID_MGMT_QUEUE_JOURNAL_MESSAGE_COUNT: UInt32 = 9
PROPID_MGMT_QUEUE_BYTES_IN_JOURNAL: UInt32 = 10
PROPID_MGMT_QUEUE_STATE: UInt32 = 11
PROPID_MGMT_QUEUE_NEXTHOPS: UInt32 = 12
PROPID_MGMT_QUEUE_EOD_LAST_ACK: UInt32 = 13
PROPID_MGMT_QUEUE_EOD_LAST_ACK_TIME: UInt32 = 14
PROPID_MGMT_QUEUE_EOD_LAST_ACK_COUNT: UInt32 = 15
PROPID_MGMT_QUEUE_EOD_FIRST_NON_ACK: UInt32 = 16
PROPID_MGMT_QUEUE_EOD_LAST_NON_ACK: UInt32 = 17
PROPID_MGMT_QUEUE_EOD_NEXT_SEQ: UInt32 = 18
PROPID_MGMT_QUEUE_EOD_NO_READ_COUNT: UInt32 = 19
PROPID_MGMT_QUEUE_EOD_NO_ACK_COUNT: UInt32 = 20
PROPID_MGMT_QUEUE_EOD_RESEND_TIME: UInt32 = 21
PROPID_MGMT_QUEUE_EOD_RESEND_INTERVAL: UInt32 = 22
PROPID_MGMT_QUEUE_EOD_RESEND_COUNT: UInt32 = 23
PROPID_MGMT_QUEUE_EOD_SOURCE_INFO: UInt32 = 24
PROPID_MGMT_QUEUE_CONNECTION_HISTORY: UInt32 = 25
PROPID_MGMT_QUEUE_SUBQUEUE_COUNT: UInt32 = 26
PROPID_MGMT_QUEUE_SUBQUEUE_NAMES: UInt32 = 27
PROPID_MGMT_QUEUE_USED_QUOTA: UInt32 = 8
PROPID_MGMT_QUEUE_JOURNAL_USED_QUOTA: UInt32 = 10
MGMT_QUEUE_TYPE_PUBLIC: String = 'PUBLIC'
MGMT_QUEUE_TYPE_PRIVATE: String = 'PRIVATE'
MGMT_QUEUE_TYPE_MACHINE: String = 'MACHINE'
MGMT_QUEUE_TYPE_CONNECTOR: String = 'CONNECTOR'
MGMT_QUEUE_TYPE_MULTICAST: String = 'MULTICAST'
MGMT_QUEUE_STATE_LOCAL: String = 'LOCAL CONNECTION'
MGMT_QUEUE_STATE_NONACTIVE: String = 'INACTIVE'
MGMT_QUEUE_STATE_WAITING: String = 'WAITING'
MGMT_QUEUE_STATE_NEED_VALIDATE: String = 'NEED VALIDATION'
MGMT_QUEUE_STATE_ONHOLD: String = 'ONHOLD'
MGMT_QUEUE_STATE_CONNECTED: String = 'CONNECTED'
MGMT_QUEUE_STATE_DISCONNECTING: String = 'DISCONNECTING'
MGMT_QUEUE_STATE_DISCONNECTED: String = 'DISCONNECTED'
MGMT_QUEUE_STATE_LOCKED: String = 'LOCKED'
MGMT_QUEUE_LOCAL_LOCATION: String = 'LOCAL'
MGMT_QUEUE_REMOTE_LOCATION: String = 'REMOTE'
MGMT_QUEUE_UNKNOWN_TYPE: String = 'UNKNOWN'
MGMT_QUEUE_CORRECT_TYPE: String = 'YES'
MGMT_QUEUE_INCORRECT_TYPE: String = 'NO'
MGMT_QUEUE_TRANSACTIONAL_TYPE: String = 'YES'
MGMT_QUEUE_NOT_TRANSACTIONAL_TYPE: String = 'NO'
MGMT_QUEUE_FOREIGN_TYPE: String = 'YES'
MGMT_QUEUE_NOT_FOREIGN_TYPE: String = 'NO'
MO_MACHINE_TOKEN: String = 'MACHINE'
MO_QUEUE_TOKEN: String = 'QUEUE'
MACHINE_ACTION_CONNECT: String = 'CONNECT'
MACHINE_ACTION_DISCONNECT: String = 'DISCONNECT'
MACHINE_ACTION_TIDY: String = 'TIDY'
QUEUE_ACTION_PAUSE: String = 'PAUSE'
QUEUE_ACTION_RESUME: String = 'RESUME'
QUEUE_ACTION_EOD_RESEND: String = 'EOD_RESEND'
LONG_LIVED: UInt32 = 4294967294
MQ_OK: win32more.Windows.Win32.Foundation.HRESULT = 0
MQ_ERROR_RESOLVE_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -1072824167
MQ_ERROR_TOO_MANY_PROPERTIES: win32more.Windows.Win32.Foundation.HRESULT = -1072824166
MQ_ERROR_MESSAGE_NOT_AUTHENTICATED: win32more.Windows.Win32.Foundation.HRESULT = -1072824165
MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION: win32more.Windows.Win32.Foundation.HRESULT = -1072824164
@winfunctype('mqrt.dll')
def MQCreateQueue(pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, pQueueProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQQUEUEPROPS), lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, lpdwFormatNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQDeleteQueue(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQLocateBegin(lpwcsContext: win32more.Windows.Win32.Foundation.PWSTR, pRestriction: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQRESTRICTION), pColumns: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQCOLUMNSET), pSort: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQSORTSET), phEnum: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQLocateNext(hEnum: win32more.Windows.Win32.Foundation.HANDLE, pcProps: POINTER(UInt32), aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQLocateEnd(hEnum: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQOpenQueue(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, dwAccess: UInt32, dwShareMode: UInt32, phQueue: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQSendMessage(hDestinationQueue: IntPtr, pMessageProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQMSGPROPS), pTransaction: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQReceiveMessage(hSource: IntPtr, dwTimeout: UInt32, dwAction: UInt32, pMessageProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQMSGPROPS), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED), fnReceiveCallback: win32more.Windows.Win32.System.MessageQueuing.PMQRECEIVECALLBACK, hCursor: win32more.Windows.Win32.Foundation.HANDLE, pTransaction: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQReceiveMessageByLookupId(hSource: IntPtr, ullLookupId: UInt64, dwLookupAction: UInt32, pMessageProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQMSGPROPS), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED), fnReceiveCallback: win32more.Windows.Win32.System.MessageQueuing.PMQRECEIVECALLBACK, pTransaction: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQCreateCursor(hQueue: IntPtr, phCursor: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQCloseCursor(hCursor: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQCloseQueue(hQueue: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQSetQueueProperties(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, pQueueProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQQUEUEPROPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetQueueProperties(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, pQueueProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQQUEUEPROPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetQueueSecurity(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, RequestedInformation: UInt32, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR, nLength: UInt32, lpnLengthNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQSetQueueSecurity(lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, SecurityInformation: win32more.Windows.Win32.Security.OBJECT_SECURITY_INFORMATION, pSecurityDescriptor: win32more.Windows.Win32.Security.PSECURITY_DESCRIPTOR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQPathNameToFormatName(lpwcsPathName: win32more.Windows.Win32.Foundation.PWSTR, lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, lpdwFormatNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQHandleToFormatName(hQueue: IntPtr, lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, lpdwFormatNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQInstanceToFormatName(pGuid: POINTER(Guid), lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, lpdwFormatNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQADsPathToFormatName(lpwcsADsPath: win32more.Windows.Win32.Foundation.PWSTR, lpwcsFormatName: win32more.Windows.Win32.Foundation.PWSTR, lpdwFormatNameLength: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQFreeMemory(pvMemory: VoidPtr) -> Void: ...
@winfunctype('mqrt.dll')
def MQGetMachineProperties(lpwcsMachineName: win32more.Windows.Win32.Foundation.PWSTR, pguidMachineId: POINTER(Guid), pQMProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQQMPROPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetSecurityContext(lpCertBuffer: VoidPtr, dwCertBufferLength: UInt32, phSecurityContext: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetSecurityContextEx(lpCertBuffer: VoidPtr, dwCertBufferLength: UInt32, phSecurityContext: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQFreeSecurityContext(hSecurityContext: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
@winfunctype('mqrt.dll')
def MQRegisterCertificate(dwFlags: UInt32, lpCertBuffer: VoidPtr, dwCertBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQBeginTransaction(ppTransaction: POINTER(win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetOverlappedResult(lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQGetPrivateComputerInformation(lpwcsComputerName: win32more.Windows.Win32.Foundation.PWSTR, pPrivateProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQPRIVATEPROPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQPurgeQueue(hQueue: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQMgmtGetInfo(pComputerName: win32more.Windows.Win32.Foundation.PWSTR, pObjectName: win32more.Windows.Win32.Foundation.PWSTR, pMgmtProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQMGMTPROPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQMgmtAction(pComputerName: win32more.Windows.Win32.Foundation.PWSTR, pObjectName: win32more.Windows.Win32.Foundation.PWSTR, pAction: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQMarkMessageRejected(hQueue: win32more.Windows.Win32.Foundation.HANDLE, ullLookupId: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('mqrt.dll')
def MQMoveMessage(hSourceQueue: IntPtr, hDestinationQueue: IntPtr, ullLookupId: UInt64, pTransaction: win32more.Windows.Win32.System.DistributedTransactionCoordinator.ITransaction) -> win32more.Windows.Win32.Foundation.HRESULT: ...
FOREIGN_STATUS = Int32
MQ_STATUS_FOREIGN: win32more.Windows.Win32.System.MessageQueuing.FOREIGN_STATUS = 0
MQ_STATUS_NOT_FOREIGN: win32more.Windows.Win32.System.MessageQueuing.FOREIGN_STATUS = 1
MQ_STATUS_UNKNOWN: win32more.Windows.Win32.System.MessageQueuing.FOREIGN_STATUS = 2
class IMSMQApplication(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e085-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def MachineIdOfMachineName(self, MachineName: win32more.Windows.Win32.Foundation.BSTR, pbstrGuid: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQApplication2(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQApplication
    _iid_ = Guid('{12a30900-7300-11d2-b0e6-00e02c074f6b}')
    @commethod(8)
    def RegisterCertificate(self, Flags: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ExternalCertificate: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def MachineNameOfMachineId(self, bstrGuid: win32more.Windows.Win32.Foundation.BSTR, pbstrMachineName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_MSMQVersionMajor(self, psMSMQVersionMajor: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_MSMQVersionMinor(self, psMSMQVersionMinor: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_MSMQVersionBuild(self, psMSMQVersionBuild: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_IsDsEnabled(self, pfIsDsEnabled: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQApplication3(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQApplication2
    _iid_ = Guid('{eba96b1f-2168-11d3-898c-00e02c074f6b}')
    @commethod(15)
    def get_ActiveQueues(self, pvActiveQueues: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_PrivateQueues(self, pvPrivateQueues: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_DirectoryServiceServer(self, pbstrDirectoryServiceServer: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_IsConnected(self, pfIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_BytesInAllQueues(self, pvBytesInAllQueues: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Machine(self, bstrMachine: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Machine(self, pbstrMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def Connect(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def Disconnect(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Tidy(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0188ac2f-ecb3-4173-9779-635ca2039c72}')
    @commethod(7)
    def Item(self, Index: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), pvarRet: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Count(self, pCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def _NewEnum(self, ppunk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQCoordinatedTransactionDispenser(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e081-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQCoordinatedTransactionDispenser2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b10-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQCoordinatedTransactionDispenser3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b14-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQDestination(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b16-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def Open(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsOpen(self, pfIsOpen: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_IADs(self, ppIADs: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def putref_IADs(self, pIADs: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ADsPath(self, pbstrADsPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_ADsPath(self, bstrADsPath: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_PathName(self, pbstrPathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_PathName(self, bstrPathName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_FormatName(self, bstrFormatName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_Destinations(self, ppDestinations: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def putref_Destinations(self, pDestinations: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e077-dccd-11d0-aa4b-0060970debae}')
class IMSMQEvent2(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent
    _iid_ = Guid('{eba96b12-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQEvent3(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent2
    _iid_ = Guid('{eba96b1c-2168-11d3-898c-00e02c074f6b}')
class IMSMQManagement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{be5f0241-e489-4957-8cc4-a452fcf3e23e}')
    @commethod(7)
    def Init(self, Machine: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Pathname: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), FormatName: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Machine(self, pbstrMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_MessageCount(self, plMessageCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ForeignStatus(self, plForeignStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_QueueType(self, plQueueType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_IsLocal(self, pfIsLocal: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_TransactionalStatus(self, plTransactionalStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_BytesInQueue(self, pvBytesInQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQMessage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e074-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def get_Class(self, plClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_AuthLevel(self, plAuthLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_AuthLevel(self, lAuthLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsAuthenticated(self, pisAuthenticated: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Delivery(self, plDelivery: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Delivery(self, lDelivery: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Trace(self, plTrace: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Trace(self, lTrace: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Priority(self, plPriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_Priority(self, lPriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ResponseQueueInfo(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def putref_ResponseQueueInfo(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_AppSpecific(self, plAppSpecific: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_AppSpecific(self, lAppSpecific: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_SourceMachineGuid(self, pbstrGuidSrcMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_BodyLength(self, pcbBody: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Body(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Body(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_AdminQueueInfo(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def putref_AdminQueueInfo(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_Id(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_CorrelationId(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_CorrelationId(self, varMsgId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_Ack(self, plAck: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_Ack(self, lAck: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_MaxTimeToReachQueue(self, plMaxTimeToReachQueue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_MaxTimeToReachQueue(self, lMaxTimeToReachQueue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_MaxTimeToReceive(self, plMaxTimeToReceive: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_MaxTimeToReceive(self, lMaxTimeToReceive: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_HashAlgorithm(self, plHashAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_HashAlgorithm(self, lHashAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_EncryptAlgorithm(self, plEncryptAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_EncryptAlgorithm(self, lEncryptAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_SentTime(self, pvarSentTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ArrivedTime(self, plArrivedTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_DestinationQueueInfo(self, ppqinfoDest: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_SenderCertificate(self, pvarSenderCert: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_SenderCertificate(self, varSenderCert: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_SenderId(self, pvarSenderId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_SenderIdType(self, plSenderIdType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_SenderIdType(self, lSenderIdType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def Send(self, DestinationQueue: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AttachCurrentSecurityContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQMessage2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d9933be0-a567-11d2-b0f3-00e02c074f6b}')
    @commethod(7)
    def get_Class(self, plClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_AuthLevel(self, plAuthLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_AuthLevel(self, lAuthLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsAuthenticated(self, pisAuthenticated: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Delivery(self, plDelivery: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Delivery(self, lDelivery: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Trace(self, plTrace: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Trace(self, lTrace: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Priority(self, plPriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_Priority(self, lPriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ResponseQueueInfo_v1(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def putref_ResponseQueueInfo_v1(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_AppSpecific(self, plAppSpecific: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_AppSpecific(self, lAppSpecific: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_SourceMachineGuid(self, pbstrGuidSrcMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_BodyLength(self, pcbBody: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Body(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Body(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_AdminQueueInfo_v1(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def putref_AdminQueueInfo_v1(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_Id(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_CorrelationId(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_CorrelationId(self, varMsgId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_Ack(self, plAck: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_Ack(self, lAck: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_MaxTimeToReachQueue(self, plMaxTimeToReachQueue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_MaxTimeToReachQueue(self, lMaxTimeToReachQueue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_MaxTimeToReceive(self, plMaxTimeToReceive: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_MaxTimeToReceive(self, lMaxTimeToReceive: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_HashAlgorithm(self, plHashAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_HashAlgorithm(self, lHashAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_EncryptAlgorithm(self, plEncryptAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_EncryptAlgorithm(self, lEncryptAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_SentTime(self, pvarSentTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ArrivedTime(self, plArrivedTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_DestinationQueueInfo(self, ppqinfoDest: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_SenderCertificate(self, pvarSenderCert: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_SenderCertificate(self, varSenderCert: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_SenderId(self, pvarSenderId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_SenderIdType(self, plSenderIdType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_SenderIdType(self, lSenderIdType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def Send(self, DestinationQueue: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue2, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AttachCurrentSecurityContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_SenderVersion(self, plSenderVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_Extension(self, pvarExtension: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_Extension(self, varExtension: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_ConnectorTypeGuid(self, pbstrGuidConnectorType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_ConnectorTypeGuid(self, bstrGuidConnectorType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_TransactionStatusQueueInfo(self, ppqinfoXactStatus: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_DestinationSymmetricKey(self, pvarDestSymmKey: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_DestinationSymmetricKey(self, varDestSymmKey: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_Signature(self, pvarSignature: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_Signature(self, varSignature: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_AuthenticationProviderType(self, plAuthProvType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_AuthenticationProviderType(self, lAuthProvType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_AuthenticationProviderName(self, pbstrAuthProvName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_AuthenticationProviderName(self, bstrAuthProvName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_SenderId(self, varSenderId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_MsgClass(self, plMsgClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_MsgClass(self, lMsgClass: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_TransactionId(self, pvarXactId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_IsFirstInTransaction(self, pisFirstInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_IsLastInTransaction(self, pisLastInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_ResponseQueueInfo(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def putref_ResponseQueueInfo(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_AdminQueueInfo(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def putref_AdminQueueInfo(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_ReceivedAuthenticationLevel(self, psReceivedAuthenticationLevel: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQMessage3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b1a-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Class(self, plClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_AuthLevel(self, plAuthLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_AuthLevel(self, lAuthLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsAuthenticated(self, pisAuthenticated: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Delivery(self, plDelivery: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Delivery(self, lDelivery: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Trace(self, plTrace: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Trace(self, lTrace: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Priority(self, plPriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_Priority(self, lPriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ResponseQueueInfo_v1(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def putref_ResponseQueueInfo_v1(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_AppSpecific(self, plAppSpecific: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_AppSpecific(self, lAppSpecific: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_SourceMachineGuid(self, pbstrGuidSrcMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_BodyLength(self, pcbBody: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Body(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Body(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_AdminQueueInfo_v1(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def putref_AdminQueueInfo_v1(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_Id(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_CorrelationId(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_CorrelationId(self, varMsgId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_Ack(self, plAck: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_Ack(self, lAck: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_MaxTimeToReachQueue(self, plMaxTimeToReachQueue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_MaxTimeToReachQueue(self, lMaxTimeToReachQueue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_MaxTimeToReceive(self, plMaxTimeToReceive: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_MaxTimeToReceive(self, lMaxTimeToReceive: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_HashAlgorithm(self, plHashAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_HashAlgorithm(self, lHashAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_EncryptAlgorithm(self, plEncryptAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_EncryptAlgorithm(self, lEncryptAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_SentTime(self, pvarSentTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ArrivedTime(self, plArrivedTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_DestinationQueueInfo(self, ppqinfoDest: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_SenderCertificate(self, pvarSenderCert: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_SenderCertificate(self, varSenderCert: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_SenderId(self, pvarSenderId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_SenderIdType(self, plSenderIdType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_SenderIdType(self, lSenderIdType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def Send(self, DestinationQueue: win32more.Windows.Win32.System.Com.IDispatch, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AttachCurrentSecurityContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_SenderVersion(self, plSenderVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_Extension(self, pvarExtension: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_Extension(self, varExtension: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_ConnectorTypeGuid(self, pbstrGuidConnectorType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_ConnectorTypeGuid(self, bstrGuidConnectorType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_TransactionStatusQueueInfo(self, ppqinfoXactStatus: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_DestinationSymmetricKey(self, pvarDestSymmKey: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_DestinationSymmetricKey(self, varDestSymmKey: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_Signature(self, pvarSignature: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_Signature(self, varSignature: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_AuthenticationProviderType(self, plAuthProvType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_AuthenticationProviderType(self, lAuthProvType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_AuthenticationProviderName(self, pbstrAuthProvName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_AuthenticationProviderName(self, bstrAuthProvName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_SenderId(self, varSenderId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_MsgClass(self, plMsgClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_MsgClass(self, lMsgClass: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_TransactionId(self, pvarXactId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_IsFirstInTransaction(self, pisFirstInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_IsLastInTransaction(self, pisLastInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_ResponseQueueInfo_v2(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def putref_ResponseQueueInfo_v2(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_AdminQueueInfo_v2(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def putref_AdminQueueInfo_v2(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_ReceivedAuthenticationLevel(self, psReceivedAuthenticationLevel: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_ResponseQueueInfo(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def putref_ResponseQueueInfo(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_AdminQueueInfo(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def putref_AdminQueueInfo(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_ResponseDestination(self, ppdestResponse: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def putref_ResponseDestination(self, pdestResponse: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_Destination(self, ppdestDestination: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_LookupId(self, pvarLookupId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_IsAuthenticated2(self, pisAuthenticated: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_IsFirstInTransaction2(self, pisFirstInXact: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_IsLastInTransaction2(self, pisLastInXact: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def AttachCurrentSecurityContext2(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_SoapEnvelope(self, pbstrSoapEnvelope: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_CompoundMessage(self, pvarCompoundMessage: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def put_SoapHeader(self, bstrSoapHeader: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_SoapBody(self, bstrSoapBody: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQMessage4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b23-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Class(self, plClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_AuthLevel(self, plAuthLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_AuthLevel(self, lAuthLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsAuthenticated(self, pisAuthenticated: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Delivery(self, plDelivery: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Delivery(self, lDelivery: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Trace(self, plTrace: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Trace(self, lTrace: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_Priority(self, plPriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_Priority(self, lPriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_ResponseQueueInfo_v1(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def putref_ResponseQueueInfo_v1(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_AppSpecific(self, plAppSpecific: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_AppSpecific(self, lAppSpecific: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_SourceMachineGuid(self, pbstrGuidSrcMachine: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_BodyLength(self, pcbBody: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Body(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Body(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_AdminQueueInfo_v1(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def putref_AdminQueueInfo_v1(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_Id(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_CorrelationId(self, pvarMsgId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_CorrelationId(self, varMsgId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_Ack(self, plAck: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def put_Ack(self, lAck: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_MaxTimeToReachQueue(self, plMaxTimeToReachQueue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def put_MaxTimeToReachQueue(self, lMaxTimeToReachQueue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_MaxTimeToReceive(self, plMaxTimeToReceive: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def put_MaxTimeToReceive(self, lMaxTimeToReceive: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_HashAlgorithm(self, plHashAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def put_HashAlgorithm(self, lHashAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_EncryptAlgorithm(self, plEncryptAlg: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_EncryptAlgorithm(self, lEncryptAlg: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_SentTime(self, pvarSentTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def get_ArrivedTime(self, plArrivedTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_DestinationQueueInfo(self, ppqinfoDest: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def get_SenderCertificate(self, pvarSenderCert: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def put_SenderCertificate(self, varSenderCert: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_SenderId(self, pvarSenderId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def get_SenderIdType(self, plSenderIdType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def put_SenderIdType(self, lSenderIdType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def Send(self, DestinationQueue: win32more.Windows.Win32.System.Com.IDispatch, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def AttachCurrentSecurityContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_SenderVersion(self, plSenderVersion: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_Extension(self, pvarExtension: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def put_Extension(self, varExtension: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_ConnectorTypeGuid(self, pbstrGuidConnectorType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def put_ConnectorTypeGuid(self, bstrGuidConnectorType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_TransactionStatusQueueInfo(self, ppqinfoXactStatus: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_DestinationSymmetricKey(self, pvarDestSymmKey: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_DestinationSymmetricKey(self, varDestSymmKey: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def get_Signature(self, pvarSignature: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def put_Signature(self, varSignature: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_AuthenticationProviderType(self, plAuthProvType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def put_AuthenticationProviderType(self, lAuthProvType: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_AuthenticationProviderName(self, pbstrAuthProvName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def put_AuthenticationProviderName(self, bstrAuthProvName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_SenderId(self, varSenderId: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_MsgClass(self, plMsgClass: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_MsgClass(self, lMsgClass: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def get_TransactionId(self, pvarXactId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def get_IsFirstInTransaction(self, pisFirstInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def get_IsLastInTransaction(self, pisLastInXact: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_ResponseQueueInfo_v2(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def putref_ResponseQueueInfo_v2(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def get_AdminQueueInfo_v2(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def putref_AdminQueueInfo_v2(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def get_ReceivedAuthenticationLevel(self, psReceivedAuthenticationLevel: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def get_ResponseQueueInfo(self, ppqinfoResponse: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def putref_ResponseQueueInfo(self, pqinfoResponse: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def get_AdminQueueInfo(self, ppqinfoAdmin: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def putref_AdminQueueInfo(self, pqinfoAdmin: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def get_ResponseDestination(self, ppdestResponse: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def putref_ResponseDestination(self, pdestResponse: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def get_Destination(self, ppdestDestination: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def get_LookupId(self, pvarLookupId: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def get_IsAuthenticated2(self, pisAuthenticated: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def get_IsFirstInTransaction2(self, pisFirstInXact: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def get_IsLastInTransaction2(self, pisLastInXact: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def AttachCurrentSecurityContext2(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def get_SoapEnvelope(self, pbstrSoapEnvelope: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def get_CompoundMessage(self, pvarCompoundMessage: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def put_SoapHeader(self, bstrSoapHeader: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def put_SoapBody(self, bstrSoapBody: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQOutgoingQueueManagement(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQManagement
    _iid_ = Guid('{64c478fb-f9b0-4695-8a7f-439ac94326d3}')
    @commethod(16)
    def get_State(self, plState: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_NextHops(self, pvNextHops: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def EodGetSendInfo(self, ppCollection: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def EodResend(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQPrivateDestination(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b17-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Handle(self, pvarHandle: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Handle(self, varHandle: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQPrivateEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7ab3341-c9d3-11d1-bb47-0080c7c5a2c0}')
    @commethod(7)
    def get_Hwnd(self, phwnd: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def FireArrivedEvent(self, pq: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue, msgcursor: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def FireArrivedErrorEvent(self, pq: win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, msgcursor: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQuery(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e072-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def LookupQueue(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQuery2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b0e-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def LookupQueue(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQuery3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b19-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def LookupQueue_v2(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LookupQueue(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), MulticastAddress: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelMulticastAddress: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQuery4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b24-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def LookupQueue_v2(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LookupQueue(self, QueueGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ServiceTypeGuid: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), Label: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), CreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelServiceType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelLabel: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), MulticastAddress: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), RelMulticastAddress: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppqinfos: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfos4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueue(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e076-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def get_Access(self, plAccess: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ShareMode(self, plShareMode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_QueueInfo(self, ppqinfo: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Handle(self, plHandle: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsOpen(self, pisOpen: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Receive(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Peek(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnableNotification(self, Event: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent, Cursor: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReceiveCurrent(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PeekNext(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def PeekCurrent(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueue2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ef0574e0-06d8-11d3-b100-00e02c074f6b}')
    @commethod(7)
    def get_Access(self, plAccess: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ShareMode(self, plShareMode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_QueueInfo(self, ppqinfo: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Handle(self, plHandle: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsOpen(self, pisOpen: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Receive_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Peek_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnableNotification(self, Event: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent2, Cursor: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReceiveCurrent_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PeekNext_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def PeekCurrent_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Receive(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Peek(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReceiveCurrent(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def PeekNext(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PeekCurrent(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueue3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b1b-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Access(self, plAccess: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ShareMode(self, plShareMode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_QueueInfo(self, ppqinfo: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Handle(self, plHandle: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsOpen(self, pisOpen: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Receive_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Peek_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnableNotification(self, Event: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent3, Cursor: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReceiveCurrent_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PeekNext_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def PeekCurrent_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Receive(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Peek(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReceiveCurrent(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def PeekNext(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PeekCurrent(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_Handle2(self, pvarHandle: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def ReceiveByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReceiveNextByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ReceivePreviousByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def ReceiveFirstByLookupId(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def ReceiveLastByLookupId(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def PeekByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def PeekNextByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def PeekPreviousByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def PeekFirstByLookupId(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def PeekLastByLookupId(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def Purge(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_IsOpen2(self, pisOpen: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueue4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b20-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_Access(self, plAccess: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ShareMode(self, plShareMode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_QueueInfo(self, ppqinfo: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Handle(self, plHandle: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsOpen(self, pisOpen: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Receive_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Peek_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def EnableNotification(self, Event: win32more.Windows.Win32.System.MessageQueuing.IMSMQEvent3, Cursor: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ReceiveCurrent_v1(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PeekNext_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def PeekCurrent_v1(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def Receive(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Peek(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def ReceiveCurrent(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def PeekNext(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def PeekCurrent(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ReceiveTimeout: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_Handle2(self, pvarHandle: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def ReceiveByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def ReceiveNextByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def ReceivePreviousByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def ReceiveFirstByLookupId(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def ReceiveLastByLookupId(self, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def PeekByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def PeekNextByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def PeekPreviousByLookupId(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def PeekFirstByLookupId(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def PeekLastByLookupId(self, WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def Purge(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_IsOpen2(self, pisOpen: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def ReceiveByLookupIdAllowPeek(self, LookupId: win32more.Windows.Win32.System.Variant.VARIANT, Transaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantDestinationQueue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), WantConnectorType: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), ppmsg: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQMessage4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e07b-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def get_QueueGuid(self, pbstrGuidQueue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ServiceTypeGuid(self, pbstrGuidServiceType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ServiceTypeGuid(self, bstrGuidServiceType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_PathName(self, pbstrPathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_PathName(self, bstrPathName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_FormatName(self, bstrFormatName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsTransactional(self, pisTransactional: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Quota(self, plQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_Quota(self, lQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_BasePriority(self, plBasePriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_BasePriority(self, lBasePriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_CreateTime(self, pvarCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_ModifyTime(self, pvarModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Authenticate(self, plAuthenticate: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Authenticate(self, lAuthenticate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_JournalQuota(self, plJournalQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_JournalQuota(self, lJournalQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_IsWorldReadable(self, pisWorldReadable: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Create(self, IsTransactional: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), IsWorldReadable: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def Open(self, Access: Int32, ShareMode: Int32, ppq: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def Update(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{fd174a80-89cf-11d2-b0f2-00e02c074f6b}')
    @commethod(7)
    def get_QueueGuid(self, pbstrGuidQueue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ServiceTypeGuid(self, pbstrGuidServiceType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ServiceTypeGuid(self, bstrGuidServiceType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_PathName(self, pbstrPathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_PathName(self, bstrPathName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_FormatName(self, bstrFormatName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsTransactional(self, pisTransactional: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Quota(self, plQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_Quota(self, lQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_BasePriority(self, plBasePriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_BasePriority(self, lBasePriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_CreateTime(self, pvarCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_ModifyTime(self, pvarModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Authenticate(self, plAuthenticate: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Authenticate(self, lAuthenticate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_JournalQuota(self, plJournalQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_JournalQuota(self, lJournalQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_IsWorldReadable(self, pisWorldReadable: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Create(self, IsTransactional: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), IsWorldReadable: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def Open(self, Access: Int32, ShareMode: Int32, ppq: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def Update(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_PathNameDNS(self, pbstrPathNameDNS: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_Security(self, pvarSecurity: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_Security(self, varSecurity: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfo3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b1d-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_QueueGuid(self, pbstrGuidQueue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ServiceTypeGuid(self, pbstrGuidServiceType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ServiceTypeGuid(self, bstrGuidServiceType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_PathName(self, pbstrPathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_PathName(self, bstrPathName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_FormatName(self, bstrFormatName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsTransactional(self, pisTransactional: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Quota(self, plQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_Quota(self, lQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_BasePriority(self, plBasePriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_BasePriority(self, lBasePriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_CreateTime(self, pvarCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_ModifyTime(self, pvarModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Authenticate(self, plAuthenticate: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Authenticate(self, lAuthenticate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_JournalQuota(self, plJournalQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_JournalQuota(self, lJournalQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_IsWorldReadable(self, pisWorldReadable: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Create(self, IsTransactional: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), IsWorldReadable: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def Open(self, Access: Int32, ShareMode: Int32, ppq: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def Update(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_PathNameDNS(self, pbstrPathNameDNS: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_Security(self, pvarSecurity: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_Security(self, varSecurity: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_IsTransactional2(self, pisTransactional: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_IsWorldReadable2(self, pisWorldReadable: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_MulticastAddress(self, pbstrMulticastAddress: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_MulticastAddress(self, bstrMulticastAddress: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_ADsPath(self, pbstrADsPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfo4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b21-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def get_QueueGuid(self, pbstrGuidQueue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ServiceTypeGuid(self, pbstrGuidServiceType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_ServiceTypeGuid(self, bstrGuidServiceType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Label(self, pbstrLabel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_Label(self, bstrLabel: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_PathName(self, pbstrPathName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_PathName(self, bstrPathName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_FormatName(self, pbstrFormatName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_FormatName(self, bstrFormatName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsTransactional(self, pisTransactional: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_PrivLevel(self, plPrivLevel: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_PrivLevel(self, lPrivLevel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Journal(self, plJournal: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_Journal(self, lJournal: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_Quota(self, plQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_Quota(self, lQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_BasePriority(self, plBasePriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_BasePriority(self, lBasePriority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_CreateTime(self, pvarCreateTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_ModifyTime(self, pvarModifyTime: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_Authenticate(self, plAuthenticate: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_Authenticate(self, lAuthenticate: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_JournalQuota(self, plJournalQuota: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def put_JournalQuota(self, lJournalQuota: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_IsWorldReadable(self, pisWorldReadable: POINTER(Int16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def Create(self, IsTransactional: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), IsWorldReadable: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def Open(self, Access: Int32, ShareMode: Int32, ppq: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueue4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def Update(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_PathNameDNS(self, pbstrPathNameDNS: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_Security(self, pvarSecurity: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def put_Security(self, varSecurity: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_IsTransactional2(self, pisTransactional: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_IsWorldReadable2(self, pisWorldReadable: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_MulticastAddress(self, pbstrMulticastAddress: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_MulticastAddress(self, bstrMulticastAddress: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_ADsPath(self, pbstrADsPath: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfos(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e07d-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, ppqinfoNext: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfos2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b0f-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, ppqinfoNext: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfos3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b1e-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, ppqinfoNext: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueInfos4(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b22-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, ppqinfoNext: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQQueueInfo4)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQQueueManagement(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQManagement
    _iid_ = Guid('{7fbe7759-5760-444d-b8a5-5e7ab9a84cce}')
    @commethod(16)
    def get_JournalMessageCount(self, plJournalMessageCount: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_BytesInJournal(self, pvBytesInJournal: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def EodGetReceiveInfo(self, pvCollection: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransaction(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e07f-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def get_Transaction(self, plTransaction: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Commit(self, fRetaining: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), grfTC: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), grfRM: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Abort(self, fRetaining: POINTER(win32more.Windows.Win32.System.Variant.VARIANT), fAsync: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransaction2(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction
    _iid_ = Guid('{2ce0c5b0-6e67-11d2-b0e6-00e02c074f6b}')
    @commethod(10)
    def InitNew(self, varTransaction: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransaction3(ComPtr):
    extends: win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction2
    _iid_ = Guid('{eba96b13-2168-11d3-898c-00e02c074f6b}')
    @commethod(12)
    def get_ITransaction(self, pvarITransaction: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransactionDispenser(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e083-dccd-11d0-aa4b-0060970debae}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransactionDispenser2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b11-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMSMQTransactionDispenser3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eba96b15-2168-11d3-898c-00e02c074f6b}')
    @commethod(7)
    def BeginTransaction(self, ptransaction: POINTER(win32more.Windows.Win32.System.MessageQueuing.IMSMQTransaction3)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Properties(self, ppcolProperties: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
MQACCESS = Int32
MQ_RECEIVE_ACCESS: win32more.Windows.Win32.System.MessageQueuing.MQACCESS = 1
MQ_SEND_ACCESS: win32more.Windows.Win32.System.MessageQueuing.MQACCESS = 2
MQ_PEEK_ACCESS: win32more.Windows.Win32.System.MessageQueuing.MQACCESS = 32
MQ_ADMIN_ACCESS: win32more.Windows.Win32.System.MessageQueuing.MQACCESS = 128
MQAUTHENTICATE = Int32
MQ_AUTHENTICATE_NONE: win32more.Windows.Win32.System.MessageQueuing.MQAUTHENTICATE = 0
MQ_AUTHENTICATE: win32more.Windows.Win32.System.MessageQueuing.MQAUTHENTICATE = 1
MQCALG = Int32
MQMSG_CALG_MD2: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32769
MQMSG_CALG_MD4: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32770
MQMSG_CALG_MD5: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32771
MQMSG_CALG_SHA: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32772
MQMSG_CALG_SHA1: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32772
MQMSG_CALG_MAC: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 32773
MQMSG_CALG_RSA_SIGN: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 9216
MQMSG_CALG_DSS_SIGN: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 8704
MQMSG_CALG_RSA_KEYX: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 41984
MQMSG_CALG_DES: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 26113
MQMSG_CALG_RC2: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 26114
MQMSG_CALG_RC4: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 26625
MQMSG_CALG_SEAL: win32more.Windows.Win32.System.MessageQueuing.MQCALG = 26626
MQCERT_REGISTER = Int32
MQCERT_REGISTER_ALWAYS: win32more.Windows.Win32.System.MessageQueuing.MQCERT_REGISTER = 1
MQCERT_REGISTER_IF_NOT_EXIST: win32more.Windows.Win32.System.MessageQueuing.MQCERT_REGISTER = 2
class MQCOLUMNSET(Structure):
    cCol: UInt32
    aCol: POINTER(UInt32)
MQConnectionState = Int32
MQCONN_NOFAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = 0
MQCONN_ESTABLISH_PACKET_RECEIVED: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = 1
MQCONN_READY: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = 2
MQCONN_UNKNOWN_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483648
MQCONN_PING_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483647
MQCONN_CREATE_SOCKET_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483646
MQCONN_BIND_SOCKET_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483645
MQCONN_CONNECT_SOCKET_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483644
MQCONN_TCP_NOT_ENABLED: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483643
MQCONN_SEND_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483642
MQCONN_NOT_READY: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483641
MQCONN_NAME_RESOLUTION_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483640
MQCONN_INVALID_SERVER_CERT: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483639
MQCONN_LIMIT_REACHED: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483638
MQCONN_REFUSED_BY_OTHER_SIDE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483637
MQCONN_ROUTING_FAILURE: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483636
MQCONN_OUT_OF_MEMORY: win32more.Windows.Win32.System.MessageQueuing.MQConnectionState = -2147483635
MQDEFAULT = Int32
DEFAULT_M_PRIORITY: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 3
DEFAULT_M_DELIVERY: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_ACKNOWLEDGE: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_JOURNAL: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_APPSPECIFIC: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_PRIV_LEVEL: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_AUTH_LEVEL: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_M_SENDERID_TYPE: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 1
DEFAULT_Q_JOURNAL: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_Q_BASEPRIORITY: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_Q_QUOTA: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = -1
DEFAULT_Q_JOURNAL_QUOTA: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = -1
DEFAULT_Q_TRANSACTION: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_Q_AUTHENTICATE: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
DEFAULT_Q_PRIV_LEVEL: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 1
DEFAULT_M_LOOKUPID: win32more.Windows.Win32.System.MessageQueuing.MQDEFAULT = 0
MQERROR = Int32
MQ_ERROR: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824319
MQ_ERROR_PROPERTY: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824318
MQ_ERROR_QUEUE_NOT_FOUND: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824317
MQ_ERROR_QUEUE_NOT_ACTIVE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824316
MQ_ERROR_QUEUE_EXISTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824315
MQ_ERROR_INVALID_PARAMETER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824314
MQ_ERROR_INVALID_HANDLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824313
MQ_ERROR_OPERATION_CANCELLED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824312
MQ_ERROR_SHARING_VIOLATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824311
MQ_ERROR_SERVICE_NOT_AVAILABLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824309
MQ_ERROR_MACHINE_NOT_FOUND: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824307
MQ_ERROR_ILLEGAL_SORT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824304
MQ_ERROR_ILLEGAL_USER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824303
MQ_ERROR_NO_DS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824301
MQ_ERROR_ILLEGAL_QUEUE_PATHNAME: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824300
MQ_ERROR_ILLEGAL_PROPERTY_VALUE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824296
MQ_ERROR_ILLEGAL_PROPERTY_VT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824295
MQ_ERROR_BUFFER_OVERFLOW: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824294
MQ_ERROR_IO_TIMEOUT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824293
MQ_ERROR_ILLEGAL_CURSOR_ACTION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824292
MQ_ERROR_MESSAGE_ALREADY_RECEIVED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824291
MQ_ERROR_ILLEGAL_FORMATNAME: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824290
MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824289
MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824288
MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824287
MQ_ERROR_SENDERID_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824286
MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824285
MQ_ERROR_CANNOT_IMPERSONATE_CLIENT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824284
MQ_ERROR_ACCESS_DENIED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824283
MQ_ERROR_PRIVILEGE_NOT_HELD: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824282
MQ_ERROR_INSUFFICIENT_RESOURCES: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824281
MQ_ERROR_USER_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824280
MQ_ERROR_MESSAGE_STORAGE_FAILED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824278
MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824277
MQ_ERROR_INVALID_CERTIFICATE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824276
MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824275
MQ_ERROR_INTERNAL_USER_CERT_EXIST: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824274
MQ_ERROR_NO_INTERNAL_USER_CERT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824273
MQ_ERROR_CORRUPTED_SECURITY_DATA: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824272
MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824271
MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824269
MQ_ERROR_BAD_SECURITY_CONTEXT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824267
MQ_ERROR_COULD_NOT_GET_USER_SID: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824266
MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824265
MQ_ERROR_ILLEGAL_MQCOLUMNS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824264
MQ_ERROR_ILLEGAL_PROPID: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824263
MQ_ERROR_ILLEGAL_RELATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824262
MQ_ERROR_ILLEGAL_PROPERTY_SIZE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824261
MQ_ERROR_ILLEGAL_RESTRICTION_PROPID: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824260
MQ_ERROR_ILLEGAL_MQQUEUEPROPS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824259
MQ_ERROR_PROPERTY_NOTALLOWED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824258
MQ_ERROR_INSUFFICIENT_PROPERTIES: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824257
MQ_ERROR_MACHINE_EXISTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824256
MQ_ERROR_ILLEGAL_MQQMPROPS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824255
MQ_ERROR_DS_IS_FULL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824254
MQ_ERROR_DS_ERROR: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824253
MQ_ERROR_INVALID_OWNER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824252
MQ_ERROR_UNSUPPORTED_ACCESS_MODE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824251
MQ_ERROR_RESULT_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824250
MQ_ERROR_DELETE_CN_IN_USE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824248
MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824247
MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824246
MQ_ERROR_QUEUE_NOT_AVAILABLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824245
MQ_ERROR_DTC_CONNECT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824244
MQ_ERROR_TRANSACTION_IMPORT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824242
MQ_ERROR_TRANSACTION_USAGE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824240
MQ_ERROR_TRANSACTION_SEQUENCE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824239
MQ_ERROR_MISSING_CONNECTOR_TYPE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824235
MQ_ERROR_STALE_HANDLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824234
MQ_ERROR_TRANSACTION_ENLIST: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824232
MQ_ERROR_QUEUE_DELETED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824230
MQ_ERROR_ILLEGAL_CONTEXT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824229
MQ_ERROR_ILLEGAL_SORT_PROPID: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824228
MQ_ERROR_LABEL_TOO_LONG: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824227
MQ_ERROR_LABEL_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824226
MQ_ERROR_MQIS_SERVER_EMPTY: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824225
MQ_ERROR_MQIS_READONLY_MODE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824224
MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824223
MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824222
MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824221
MQ_ERROR_ILLEGAL_OPERATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824220
MQ_ERROR_WRITE_NOT_ALLOWED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824219
MQ_ERROR_WKS_CANT_SERVE_CLIENT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824218
MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824217
MQ_CORRUPTED_QUEUE_WAS_DELETED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824216
MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824215
MQ_ERROR_UNSUPPORTED_OPERATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824214
MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824213
MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824212
MQ_ERROR_CERTIFICATE_NOT_PROVIDED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824211
MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824210
MQ_ERROR_CANT_CREATE_CERT_STORE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824209
MQ_ERROR_CANNOT_CREATE_CERT_STORE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824209
MQ_ERROR_CANT_OPEN_CERT_STORE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824208
MQ_ERROR_CANNOT_OPEN_CERT_STORE: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824208
MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824207
MQ_ERROR_CANNOT_GRANT_ADD_GUID: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824206
MQ_ERROR_CANNOT_LOAD_MSMQOCM: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824205
MQ_ERROR_NO_ENTRY_POINT_MSMQOCM: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824204
MQ_ERROR_NO_MSMQ_SERVERS_ON_DC: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824203
MQ_ERROR_CANNOT_JOIN_DOMAIN: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824202
MQ_ERROR_CANNOT_CREATE_ON_GC: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824201
MQ_ERROR_GUID_NOT_MATCHING: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824200
MQ_ERROR_PUBLIC_KEY_NOT_FOUND: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824199
MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824198
MQ_ERROR_ILLEGAL_MQPRIVATEPROPS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824197
MQ_ERROR_NO_GC_IN_DOMAIN: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824196
MQ_ERROR_NO_MSMQ_SERVERS_ON_GC: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824195
MQ_ERROR_CANNOT_GET_DN: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824194
MQ_ERROR_CANNOT_HASH_DATA_EX: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824193
MQ_ERROR_CANNOT_SIGN_DATA_EX: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824192
MQ_ERROR_CANNOT_CREATE_HASH_EX: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824191
MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824190
MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824189
MQ_ERROR_NO_MQUSER_OU: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824188
MQ_ERROR_CANNOT_LOAD_MQAD: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824187
MQ_ERROR_CANNOT_LOAD_MQDSSRV: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824186
MQ_ERROR_PROPERTIES_CONFLICT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824185
MQ_ERROR_MESSAGE_NOT_FOUND: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824184
MQ_ERROR_CANT_RESOLVE_SITES: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824183
MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824182
MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824181
MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824180
MQ_ERROR_MULTI_SORT_KEYS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824179
MQ_ERROR_GC_NEEDED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824178
MQ_ERROR_DS_BIND_ROOT_FOREST: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824177
MQ_ERROR_DS_LOCAL_USER: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824176
MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824175
MQ_ERROR_BAD_XML_FORMAT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824174
MQ_ERROR_UNSUPPORTED_CLASS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824173
MQ_ERROR_UNINITIALIZED_OBJECT: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824172
MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824171
MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS: win32more.Windows.Win32.System.MessageQueuing.MQERROR = -1072824170
MQJOURNAL = Int32
MQ_JOURNAL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQJOURNAL = 0
MQ_JOURNAL: win32more.Windows.Win32.System.MessageQueuing.MQJOURNAL = 1
MQMAX = Int32
MQ_MAX_Q_NAME_LEN: win32more.Windows.Win32.System.MessageQueuing.MQMAX = 124
MQ_MAX_Q_LABEL_LEN: win32more.Windows.Win32.System.MessageQueuing.MQMAX = 124
class MQMGMTPROPS(Structure):
    cProp: UInt32
    aPropID: POINTER(UInt32)
    aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
    aStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)
MQMSGACKNOWLEDGEMENT = Int32
MQMSG_ACKNOWLEDGMENT_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 0
MQMSG_ACKNOWLEDGMENT_POS_ARRIVAL: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 1
MQMSG_ACKNOWLEDGMENT_POS_RECEIVE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 2
MQMSG_ACKNOWLEDGMENT_NEG_ARRIVAL: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 4
MQMSG_ACKNOWLEDGMENT_NEG_RECEIVE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 8
MQMSG_ACKNOWLEDGMENT_NACK_REACH_QUEUE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 4
MQMSG_ACKNOWLEDGMENT_FULL_REACH_QUEUE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 5
MQMSG_ACKNOWLEDGMENT_NACK_RECEIVE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 12
MQMSG_ACKNOWLEDGMENT_FULL_RECEIVE: win32more.Windows.Win32.System.MessageQueuing.MQMSGACKNOWLEDGEMENT = 14
MQMSGAUTHENTICATION = Int32
MQMSG_AUTHENTICATION_NOT_REQUESTED: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 0
MQMSG_AUTHENTICATION_REQUESTED: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 1
MQMSG_AUTHENTICATED_SIG10: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 1
MQMSG_AUTHENTICATION_REQUESTED_EX: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 3
MQMSG_AUTHENTICATED_SIG20: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 3
MQMSG_AUTHENTICATED_SIG30: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 5
MQMSG_AUTHENTICATED_SIGXML: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHENTICATION = 9
MQMSGAUTHLEVEL = Int32
MQMSG_AUTH_LEVEL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 0
MQMSG_AUTH_LEVEL_ALWAYS: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 1
MQMSG_AUTH_LEVEL_MSMQ10: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 2
MQMSG_AUTH_LEVEL_SIG10: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 2
MQMSG_AUTH_LEVEL_MSMQ20: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 4
MQMSG_AUTH_LEVEL_SIG20: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 4
MQMSG_AUTH_LEVEL_SIG30: win32more.Windows.Win32.System.MessageQueuing.MQMSGAUTHLEVEL = 8
MQMSGCLASS = Int32
MQMSG_CLASS_NORMAL: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 0
MQMSG_CLASS_REPORT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 1
MQMSG_CLASS_ACK_REACH_QUEUE: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 2
MQMSG_CLASS_ACK_RECEIVE: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 16384
MQMSG_CLASS_NACK_BAD_DST_Q: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32768
MQMSG_CLASS_NACK_PURGED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32769
MQMSG_CLASS_NACK_REACH_QUEUE_TIMEOUT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32770
MQMSG_CLASS_NACK_Q_EXCEED_QUOTA: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32771
MQMSG_CLASS_NACK_ACCESS_DENIED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32772
MQMSG_CLASS_NACK_HOP_COUNT_EXCEEDED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32773
MQMSG_CLASS_NACK_BAD_SIGNATURE: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32774
MQMSG_CLASS_NACK_BAD_ENCRYPTION: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32775
MQMSG_CLASS_NACK_COULD_NOT_ENCRYPT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32776
MQMSG_CLASS_NACK_NOT_TRANSACTIONAL_Q: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32777
MQMSG_CLASS_NACK_NOT_TRANSACTIONAL_MSG: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32778
MQMSG_CLASS_NACK_UNSUPPORTED_CRYPTO_PROVIDER: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32779
MQMSG_CLASS_NACK_SOURCE_COMPUTER_GUID_CHANGED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 32780
MQMSG_CLASS_NACK_Q_DELETED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 49152
MQMSG_CLASS_NACK_Q_PURGED: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 49153
MQMSG_CLASS_NACK_RECEIVE_TIMEOUT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 49154
MQMSG_CLASS_NACK_RECEIVE_TIMEOUT_AT_SENDER: win32more.Windows.Win32.System.MessageQueuing.MQMSGCLASS = 49155
MQMSGCURSOR = Int32
MQMSG_FIRST: win32more.Windows.Win32.System.MessageQueuing.MQMSGCURSOR = 0
MQMSG_CURRENT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCURSOR = 1
MQMSG_NEXT: win32more.Windows.Win32.System.MessageQueuing.MQMSGCURSOR = 2
MQMSGDELIVERY = Int32
MQMSG_DELIVERY_EXPRESS: win32more.Windows.Win32.System.MessageQueuing.MQMSGDELIVERY = 0
MQMSG_DELIVERY_RECOVERABLE: win32more.Windows.Win32.System.MessageQueuing.MQMSGDELIVERY = 1
MQMSGIDSIZE = Int32
MQMSG_MSGID_SIZE: win32more.Windows.Win32.System.MessageQueuing.MQMSGIDSIZE = 20
MQMSG_CORRELATIONID_SIZE: win32more.Windows.Win32.System.MessageQueuing.MQMSGIDSIZE = 20
MQMSG_XACTID_SIZE: win32more.Windows.Win32.System.MessageQueuing.MQMSGIDSIZE = 20
MQMSGJOURNAL = Int32
MQMSG_JOURNAL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGJOURNAL = 0
MQMSG_DEADLETTER: win32more.Windows.Win32.System.MessageQueuing.MQMSGJOURNAL = 1
MQMSG_JOURNAL: win32more.Windows.Win32.System.MessageQueuing.MQMSGJOURNAL = 2
MQMSGMAX = Int32
MQ_MAX_MSG_LABEL_LEN: win32more.Windows.Win32.System.MessageQueuing.MQMSGMAX = 249
MQMSGPRIVLEVEL = Int32
MQMSG_PRIV_LEVEL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGPRIVLEVEL = 0
MQMSG_PRIV_LEVEL_BODY_BASE: win32more.Windows.Win32.System.MessageQueuing.MQMSGPRIVLEVEL = 1
MQMSG_PRIV_LEVEL_BODY_ENHANCED: win32more.Windows.Win32.System.MessageQueuing.MQMSGPRIVLEVEL = 3
class MQMSGPROPS(Structure):
    cProp: UInt32
    aPropID: POINTER(UInt32)
    aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
    aStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)
MQMSGSENDERIDTYPE = Int32
MQMSG_SENDERID_TYPE_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGSENDERIDTYPE = 0
MQMSG_SENDERID_TYPE_SID: win32more.Windows.Win32.System.MessageQueuing.MQMSGSENDERIDTYPE = 1
MQMSGTRACE = Int32
MQMSG_TRACE_NONE: win32more.Windows.Win32.System.MessageQueuing.MQMSGTRACE = 0
MQMSG_SEND_ROUTE_TO_REPORT_QUEUE: win32more.Windows.Win32.System.MessageQueuing.MQMSGTRACE = 1
MQPRIORITY = Int32
MQ_MIN_PRIORITY: win32more.Windows.Win32.System.MessageQueuing.MQPRIORITY = 0
MQ_MAX_PRIORITY: win32more.Windows.Win32.System.MessageQueuing.MQPRIORITY = 7
class MQPRIVATEPROPS(Structure):
    cProp: UInt32
    aPropID: POINTER(UInt32)
    aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
    aStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)
MQPRIVLEVEL = Int32
MQ_PRIV_LEVEL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQPRIVLEVEL = 0
MQ_PRIV_LEVEL_OPTIONAL: win32more.Windows.Win32.System.MessageQueuing.MQPRIVLEVEL = 1
MQ_PRIV_LEVEL_BODY: win32more.Windows.Win32.System.MessageQueuing.MQPRIVLEVEL = 2
class MQPROPERTYRESTRICTION(Structure):
    rel: UInt32
    prop: UInt32
    prval: win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT
class MQQMPROPS(Structure):
    cProp: UInt32
    aPropID: POINTER(UInt32)
    aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
    aStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)
MQQUEUEACCESSMASK = UInt32
MQSEC_DELETE_QUEUE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 65536
MQSEC_GET_QUEUE_PERMISSIONS: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 131072
MQSEC_CHANGE_QUEUE_PERMISSIONS: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 262144
MQSEC_TAKE_QUEUE_OWNERSHIP: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 524288
MQSEC_RECEIVE_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 3
MQSEC_RECEIVE_JOURNAL_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 10
MQSEC_QUEUE_GENERIC_READ: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 131115
MQSEC_QUEUE_GENERIC_WRITE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 131108
MQSEC_QUEUE_GENERIC_ALL: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 983103
MQSEC_DELETE_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 1
MQSEC_PEEK_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 2
MQSEC_WRITE_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 4
MQSEC_DELETE_JOURNAL_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 8
MQSEC_SET_QUEUE_PROPERTIES: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 16
MQSEC_GET_QUEUE_PROPERTIES: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 32
MQSEC_QUEUE_GENERIC_EXECUTE: win32more.Windows.Win32.System.MessageQueuing.MQQUEUEACCESSMASK = 0
class MQQUEUEPROPS(Structure):
    cProp: UInt32
    aPropID: POINTER(UInt32)
    aPropVar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)
    aStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)
class MQRESTRICTION(Structure):
    cRes: UInt32
    paPropRes: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQPROPERTYRESTRICTION)
MQSHARE = Int32
MQ_DENY_NONE: win32more.Windows.Win32.System.MessageQueuing.MQSHARE = 0
MQ_DENY_RECEIVE_SHARE: win32more.Windows.Win32.System.MessageQueuing.MQSHARE = 1
class MQSORTKEY(Structure):
    propColumn: UInt32
    dwOrder: UInt32
class MQSORTSET(Structure):
    cCol: UInt32
    aCol: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQSORTKEY)
MQTRANSACTION = Int32
MQ_NO_TRANSACTION: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTION = 0
MQ_MTS_TRANSACTION: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTION = 1
MQ_XA_TRANSACTION: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTION = 2
MQ_SINGLE_MESSAGE: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTION = 3
MQTRANSACTIONAL = Int32
MQ_TRANSACTIONAL_NONE: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTIONAL = 0
MQ_TRANSACTIONAL: win32more.Windows.Win32.System.MessageQueuing.MQTRANSACTIONAL = 1
MQWARNING = Int32
MQ_INFORMATION_PROPERTY: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659329
MQ_INFORMATION_ILLEGAL_PROPERTY: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659330
MQ_INFORMATION_PROPERTY_IGNORED: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659331
MQ_INFORMATION_UNSUPPORTED_PROPERTY: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659332
MQ_INFORMATION_DUPLICATE_PROPERTY: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659333
MQ_INFORMATION_OPERATION_PENDING: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659334
MQ_INFORMATION_FORMATNAME_BUFFER_TOO_SMALL: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659337
MQ_INFORMATION_INTERNAL_USER_CERT_EXIST: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659338
MQ_INFORMATION_OWNER_IGNORED: win32more.Windows.Win32.System.MessageQueuing.MQWARNING = 1074659339
MSMQApplication = Guid('{d7d6e086-dccd-11d0-aa4b-0060970debae}')
MSMQCollection = Guid('{f72b9031-2f0c-43e8-924e-e6052cdc493f}')
MSMQCoordinatedTransactionDispenser = Guid('{d7d6e082-dccd-11d0-aa4b-0060970debae}')
MSMQDestination = Guid('{eba96b18-2168-11d3-898c-00e02c074f6b}')
MSMQEvent = Guid('{d7d6e07a-dccd-11d0-aa4b-0060970debae}')
MSMQManagement = Guid('{39ce96fe-f4c5-4484-a143-4c2d5d324229}')
MSMQMessage = Guid('{d7d6e075-dccd-11d0-aa4b-0060970debae}')
MSMQOutgoingQueueManagement = Guid('{0188401c-247a-4fed-99c6-bf14119d7055}')
MSMQQuery = Guid('{d7d6e073-dccd-11d0-aa4b-0060970debae}')
MSMQQueue = Guid('{d7d6e079-dccd-11d0-aa4b-0060970debae}')
MSMQQueueInfo = Guid('{d7d6e07c-dccd-11d0-aa4b-0060970debae}')
MSMQQueueInfos = Guid('{d7d6e07e-dccd-11d0-aa4b-0060970debae}')
MSMQQueueManagement = Guid('{33b6d07e-f27d-42fa-b2d7-bf82e11e9374}')
MSMQTransaction = Guid('{d7d6e080-dccd-11d0-aa4b-0060970debae}')
MSMQTransactionDispenser = Guid('{d7d6e084-dccd-11d0-aa4b-0060970debae}')
@winfunctype_pointer
def PMQRECEIVECALLBACK(hrStatus: win32more.Windows.Win32.Foundation.HRESULT, hSource: IntPtr, dwTimeout: UInt32, dwAction: UInt32, pMessageProps: POINTER(win32more.Windows.Win32.System.MessageQueuing.MQMSGPROPS), lpOverlapped: POINTER(win32more.Windows.Win32.System.IO.OVERLAPPED), hCursor: win32more.Windows.Win32.Foundation.HANDLE) -> Void: ...
QUEUE_STATE = Int32
MQ_QUEUE_STATE_LOCAL_CONNECTION: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 0
MQ_QUEUE_STATE_DISCONNECTED: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 1
MQ_QUEUE_STATE_WAITING: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 2
MQ_QUEUE_STATE_NEEDVALIDATE: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 3
MQ_QUEUE_STATE_ONHOLD: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 4
MQ_QUEUE_STATE_NONACTIVE: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 5
MQ_QUEUE_STATE_CONNECTED: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 6
MQ_QUEUE_STATE_DISCONNECTING: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 7
MQ_QUEUE_STATE_LOCKED: win32more.Windows.Win32.System.MessageQueuing.QUEUE_STATE = 8
QUEUE_TYPE = Int32
MQ_TYPE_PUBLIC: win32more.Windows.Win32.System.MessageQueuing.QUEUE_TYPE = 0
MQ_TYPE_PRIVATE: win32more.Windows.Win32.System.MessageQueuing.QUEUE_TYPE = 1
MQ_TYPE_MACHINE: win32more.Windows.Win32.System.MessageQueuing.QUEUE_TYPE = 2
MQ_TYPE_CONNECTOR: win32more.Windows.Win32.System.MessageQueuing.QUEUE_TYPE = 3
MQ_TYPE_MULTICAST: win32more.Windows.Win32.System.MessageQueuing.QUEUE_TYPE = 4
RELOPS = Int32
REL_NOP: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 0
REL_EQ: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 1
REL_NEQ: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 2
REL_LT: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 3
REL_GT: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 4
REL_LE: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 5
REL_GE: win32more.Windows.Win32.System.MessageQueuing.RELOPS = 6
class SEQUENCE_INFO(Structure):
    SeqID: Int64
    SeqNo: UInt32
    PrevNo: UInt32
XACT_STATUS = Int32
MQ_XACT_STATUS_XACT: win32more.Windows.Win32.System.MessageQueuing.XACT_STATUS = 0
MQ_XACT_STATUS_NOT_XACT: win32more.Windows.Win32.System.MessageQueuing.XACT_STATUS = 1
MQ_XACT_STATUS_UNKNOWN: win32more.Windows.Win32.System.MessageQueuing.XACT_STATUS = 2
class _DMSMQEventEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d7d6e078-dccd-11d0-aa4b-0060970debae}')


make_ready(__name__)
